# Zernipax
A python library to calculate Zernike Polynomials fast and accurately using JAX.


To create conda environment:
```
conda create --name zernipax-env 'python>=3.8, <=3.12'
conda activate zernipax-env
pip install -r requirements.txt
```

or, if you want to contribute
```
pip install -r dev-requirement.txt
```
